@@ -1,3 +1,24 @@
+#' Plot used to visually assess the amount of bias of a new measurement method
+#'  relative to a reference standard
+#'
+#' This function draws the "bias plot" which is used to visually assess the bias
+#'  of the new method relative to a reference method. It is obtained by graphing a scatter plot
+#'  of  \eqn{y_{1ij}} (new method) and \eqn{y_{2ij}} (reference method) versus the BLUP of y2 along with the two regression lines, and
+#'  adds a second scale on the right showing the relationship between the
+#'  estimated amount of bias and BLUP of y2.
+#'
+#' @param object an object returned by a call to \link{measure_compare}
+#' @author  Mingkai Peng
+#' @importFrom graphics abline axis box legend mtext par plot points title
+#' @export
+#' @examples
+#' ### load the data
+#' data(data1)
+#' ### analysis
+#' measure_model <- measure_compare(data1)
+#' ### Bias plot
+#' bias_plot(measure_model)
+#'
 
 bias_plot <- function(object){
         ### extract the objects from the output
@@ -18,9 +39,12 @@ bias_plot <- function(object){
              col="grey",ylim = c(min_y,max_y),cex=0.5)
         title(main="Bias",cex.main=0.9)
         points(data_new$y2_hat,data_new$y1,col="blue",pch=19,cex=0.5)
+
         ### Add the fitted line from model 2 and model 4,
-        abline(Models[[2]]$coefficients,lwd=2)
+        #abline(Models[[2]]$coefficients,lwd=2)
+        abline(c(0,1),lwd=2)
         abline(Models[[4]]$coefficients,lwd=2,lty=2,col="blue")
+
         ### Add the subtitle
         mtext(subtitle,side=3,cex=0.8)
         ### Add the left y axis
@@ -41,7 +65,7 @@ bias_plot <- function(object){
         axis(1)
         mtext("BLUP of x",side=1,col="black",line=2)
         ### Add the legend
-        lm_bias <- lm(data_new$Bias ~data_new$y2_hat)
+        lm_bias <- lm(data_new$Bias~data_new$y2_hat)
         if (coef(lm_bias)[2] <0){
         legend("top",legend=c("Reference method (y2)","New method (y1)","Bias"),
                pch = c(1,19),col = c("black","blue","red"),pt.cex=c(1,1,0.0001),
